## Description

Please clearly and concisely describe the changes made in this merge request. Include the following:

- Purpose and goals of the changes
- Problem(s) being solved
- High-level overview of the implementation
- References to relevant ticket numbers and acceptance criteria (if applicable)

## Changes

Please list the main changes made in this pull request:

- Change 1
- Change 2
- ...

## Checklist for the Author

- [ ] The code is well-structured, readable, and maintainable
- [ ] The changes meet all acceptance criteria
- [ ] Edge cases and error scenarios are handled appropriately
- [ ] The code includes appropriate unit tests and/or integration tests
- [ ] The code follows the project's coding conventions and best practices
- [ ] The changes have been manually tested and verified
- [ ] The code uses existing UI components where appropriate
- [ ] New UI components, if any, are included in Storybook
- [ ] The introduction of new library dependencies is well justified
- [ ] SSR has been taken into account, if applicable.
- [ ] High-level documentation is updated, if necessary (with corresponding MRs linked)

## Checklist for the Reviewer

- [ ] Review the code for clarity, readability, and maintainability
- [ ] Verify that the changes meet all acceptance criteria
- [ ] Check for proper handling of edge cases and error scenarios
- [ ] Review the test coverage and ensure critical paths are tested
- [ ] Verify that the code follows the project's coding conventions and best practices
- [ ] Perform manual testing to validate the changes work as expected
- [ ] Ensure that new UI components, if any, are properly integrated and documented
- [ ] Verify that new library dependencies, if introduced, are justified and necessary
- [ ] Check for any missing updates to high-level documentation

## Testing Steps for the Reviewer

Please provide detailed testing steps for the reviewer to follow:

- [ ] Step 1
- [ ] Step 2
- [ ] ...

Include expected outcomes and any specific areas or scenarios that require extra attention.

## Additional Notes

Please include any additional information, context, or considerations that may be helpful for the reviewer.

## References

See https://oss.holi.social/docs/contributing/code-review-checklist.
